==> acquia_contenthub-3.3.x-dev.tar.gz: acquia_contenthub/modules/acquia_contenthub_subscriber/src/EventSubscriber/EntityDataTamper/DisabledEntity.php <==
<?php

namespace Drupal\acquia_contenthub_subscriber\EventSubscriber\EntityDataTamper;

use Drupal\acquia_contenthub\AcquiaContentHubEvents;
use Drupal\acquia_contenthub\Event\EntityDataTamperEvent;
use Drupal\acquia_contenthub_subscriber\Libs\InterestList\InterestListTracker;
use Drupal\acquia_contenthub_subscriber\SubscriberTracker;
use Drupal\depcalc\DependentEntityWrapper;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Place entities that are marked disabled for syndication.
 *
 * Into the dependency stack.
 */
class DisabledEntity implements EventSubscriberInterface {

  /**
   * The subscriber tracker.
   *
   * @var \Drupal\acquia_contenthub_subscriber\SubscriberTracker
   */
  protected SubscriberTracker $tracker;

  /**
   * Interest list tracker.
   *
   * @var \Drupal\acquia_contenthub_subscriber\Libs\InterestList\InterestListTracker
   */
  protected InterestListTracker $interestListTracker;

  /**
   * DisabledEntity constructor.
   *
   * @param \Drupal\acquia_contenthub_subscriber\SubscriberTracker $tracker
   *   Subscriber tracker.
   * @param \Drupal\acquia_contenthub_subscriber\Libs\InterestList\InterestListTracker $interest_list_tracker
   *   Interest list tracker.
   *
   * @throws \Exception
   */
  public function __construct(SubscriberTracker $tracker, InterestListTracker $interest_list_tracker) {
    $this->tracker = $tracker;
    $this->interestListTracker = $interest_list_tracker;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AcquiaContentHubEvents::ENTITY_DATA_TAMPER][] = [
      'onDataTamper',
      100,
    ];

    return $events;
  }

  /**
   * Tamper with CDF data before its imported.
   *
   * @param \Drupal\acquia_contenthub\Event\EntityDataTamperEvent $event
   *   The data tamper event.
   *
   * @throws \Exception
   */
  public function onDataTamper(EntityDataTamperEvent $event) {
    $cdf = $event->getCdf();
    $disabled_entities = $this->getDisabledEntities();
    foreach ($cdf->getEntities() as $object) {
      $uuid = $object->getUuid();
      if (!in_array($uuid, $disabled_entities, TRUE)) {
        continue;
      }
      if ($this->tracker->getStatusByUuid($uuid) !== SubscriberTracker::AUTO_UPDATE_DISABLED) {
        continue;
      }
      $entity = $this->tracker->getEntityByRemoteIdAndHash($uuid);
      if ($entity) {
        $wrapper = new DependentEntityWrapper($entity);
        $wrapper->setRemoteUuid($uuid);
        $event->getStack()->addDependency($wrapper);
      }
    }
  }

  /**
   * Fetches the disabled entities from interest list tracker.
   *
   * @return array
   *   List of uuids that are disabled.
   *
   * @throws \Exception
   */
  public function getDisabledEntities(): array {
    $disabled_uuids = $this->interestListTracker->getDisabledEntities();
    if (!empty($disabled_uuids)) {
      $this->tracker->setStatusByUuids($disabled_uuids, SubscriberTracker::AUTO_UPDATE_DISABLED);
    }
    return $disabled_uuids;
  }

}

==> acquia_contenthub-3.5.x-dev.tar.gz: acquia_contenthub/modules/acquia_contenthub_subscriber/src/EventSubscriber/EntityDataTamper/DisabledEntity.php <==
<?php

namespace Drupal\acquia_contenthub_subscriber\EventSubscriber\EntityDataTamper;

use Drupal\acquia_contenthub\AcquiaContentHubEvents;
use Drupal\acquia_contenthub\Event\EntityDataTamperEvent;
use Drupal\acquia_contenthub_subscriber\Libs\InterestList\InterestListTracker;
use Drupal\acquia_contenthub_subscriber\SubscriberTracker;
use Drupal\depcalc\DependentEntityWrapper;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * Place entities that are marked disabled for syndication.
 *
 * Into the dependency stack.
 */
class DisabledEntity implements EventSubscriberInterface {

  /**
   * The subscriber tracker.
   *
   * @var \Drupal\acquia_contenthub_subscriber\SubscriberTracker
   */
  protected SubscriberTracker $tracker;

  /**
   * Interest list tracker.
   *
   * @var \Drupal\acquia_contenthub_subscriber\Libs\InterestList\InterestListTracker
   */
  protected InterestListTracker $interestListTracker;

  /**
   * DisabledEntity constructor.
   *
   * @param \Drupal\acquia_contenthub_subscriber\SubscriberTracker $tracker
   *   Subscriber tracker.
   * @param \Drupal\acquia_contenthub_subscriber\Libs\InterestList\InterestListTracker $interest_list_tracker
   *   Interest list tracker.
   *
   * @throws \Exception
   */
  public function __construct(SubscriberTracker $tracker, InterestListTracker $interest_list_tracker) {
    $this->tracker = $tracker;
    $this->interestListTracker = $interest_list_tracker;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    $events[AcquiaContentHubEvents::ENTITY_DATA_TAMPER][] = [
      'onDataTamper',
      100,
    ];

    return $events;
  }

  /**
   * Tamper with CDF data before its imported.
   *
   * @param \Drupal\acquia_contenthub\Event\EntityDataTamperEvent $event
   *   The data tamper event.
   *
   * @throws \Exception
   */
  public function onDataTamper(EntityDataTamperEvent $event) {
    $cdf = $event->getCdf();
    $disabled_entities = $this->getDisabledEntities();
    foreach ($cdf->getEntities() as $object) {
      $uuid = $object->getUuid();
      if (!in_array($uuid, $disabled_entities, TRUE)) {
        continue;
      }
      if ($this->tracker->getStatusByUuid($uuid) !== SubscriberTracker::AUTO_UPDATE_DISABLED) {
        continue;
      }
      $entity = $this->tracker->getEntityByRemoteIdAndHash($uuid);
      if ($entity) {
        $wrapper = new DependentEntityWrapper($entity);
        $wrapper->setRemoteUuid($uuid);
        $event->getStack()->addDependency($wrapper, FALSE);
      }
    }
  }

  /**
   * Fetches the disabled entities from interest list tracker.
   *
   * @return array
   *   List of uuids that are disabled.
   *
   * @throws \Exception
   */
  public function getDisabledEntities(): array {
    $disabled_uuids = $this->interestListTracker->getDisabledEntities();
    if (!empty($disabled_uuids)) {
      $this->tracker->setStatusByUuids($disabled_uuids, SubscriberTracker::AUTO_UPDATE_DISABLED);
    }
    return $disabled_uuids;
  }

}
